@@ -16,7 +16,7 @@ use bytes;
 use Try::Catch;
 
 # Set the package version. 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -436,61 +436,88 @@ __END__
 
 =head1 NAME
 
-Terminal::Control - Perl extension for the terminal window control
+Terminal::Control - Perl extension with methods for the control of the terminal window
+
+=head1 ABSTRACT
+
+The module contains, among others, two methods for clearing and
+resetting the terminal window. This is a standard task when
+scripts has to be executed in the terminal window. The realted 
+Shell commands are slow in comparison to the presented module
+commands. This is achieved by using ANSI escape sequences. XTERM
+control sequences can be used to query screen and window data.
+The terminal or window size is available via the system call ioctl.
 
 =head1 SYNOPSIS
 
   use Terminal::Control;
 
-  # Clear screen using escape sequences.
+  # Clear the terminal window using ANSI escape sequences.
   clear_screen();
 
-  # Reset screen using escape sequences.
+  # Reset the terminal window using ANSI escape sequences.
   reset_screen();
 
-  # Get terminal size calling ioctl and output the result on the screen.
+  # Get the window size calling ioctl and output the result on the screen.
   my ($rows, $cols, $xpix, $ypix) = winsize();
   printf ("%s\n%s\n%s\n%s\n", $rows, $cols, $xpix, $ypix);
 
-  # Get chars from terminal size and output the result on the screen.
+  # Get the chars from the window size and output the result on the screen.
   ($rows, $cols) = chars();
-  # Print chars.
   printf ("%s\n%s\n", $rows, $cols);
 
-  # Get pixels from terminal size and output the result on the screen.
+  # Get the pixels from the window size and output the result on the screen.
   ($xpix, $ypix) = pixels();
   printf ("%s\n%s\n", $xpix, $ypix);
 
-  # Get the cursor position using escape sequences.
-  my ($y, $x) = get_cursor_position();
-  printf ("%s\n%s\n", $y, $x);
+  # Get the cursor position using ANSI escape sequences.
+  my ($row, $col) = get_cursor_position();
+  printf ("%s\n%s\n", $rows, $cols);
 
-  # Set the cursor position in chars not in pixels using escape sequences.
+  # Set the cursor position in chars (not in pixels) using ANSI escape sequences.
   my $rows = 20; 
   my $cols = 80; 
-  set_cursor_position($rows, $cols); # $rows and $cols must be set by the user
+  # $row and $col are required and must be set by the user.
+  set_cursor_position($row, $col);
 
-  # Enable echo of commands using stty. 
+  # Enable echoing of commands using stty. 
   echo_on();
 
-  # Disable echo of commands using stty. 
+  # Disable echoing of commands using stty. 
   echo_off();
 
-  # Enable cursor using escape sequences.
+  # Enable visibility of the cursor using ANSI escape sequences.
   cursor_on();
 
-  # Disable cursor using escape sequences.
+  # Disable visibility of the cursor using ANSI escape sequences.
   cursor_off();
 
-  # Set timeout in microseconds.
+  # Set the timeout for reading from STDIN in microseconds.
   my $timeout = 1000000;
-  # Get window and screen size using escape sequences.
-  window_size_chars($timeout);   # $timeout is optional. if not set 1000000 microseconds (1 second) is used.
-  windows_size_pixels($timeout); # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
-  screen_size_chars($timeout);   # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
-  screen_size_pixels($timeout);  # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
+  # Get the window and the screen size using XTERM control sequences.
+  # $timeout is optional. If not set 1000000 microseconds (1 second) are used.
+  window_size_chars($timeout);  
+  windows_size_pixels($timeout);
+  screen_size_chars($timeout); 
+  screen_size_pixels($timeout);
 
-=head1 Motivation for Development
+=head1 VARIABLES EXPLANATION
+
+The x-direction is corresponding to window width and the y-direction is
+corresponding to window height.
+
+  $row     => Row (y-position) of terminal window as char position
+  $col     => Column (x-position) of terminal window as char position
+  $rows    => Rows (height) of terminal window as chars
+  $cols    => Columns (width) of terminal window as chars
+  $ypix    => Rows (y-direction or height) of terminal window as pixels
+  $xpix    => Coulumns (x-direction or width) of terminal window as pixels
+  $timeout => Timeout for reading from STDIN in microseconds
+
+The predefined value of $timeout is 1000000 microseconds (1 second). The
+value of the parameter $timeout has to be given in microseconds.  
+
+=head1 DEVELOPMENT MOTIVATION
 
 The idea for the necessity of the module arises from the fact that especially 
 the call of the Perl command system C<system("reset")> of the Shell command
@@ -505,7 +532,7 @@ A single method is the best way to realise this for the terminal reset and
 several other commands. There is no need to implement a class with a bunch of
 methods to achive this.  
 
-=head1 Prove of Concept
+=head1 PROVE OF CONCEPT
 
 Exemplary comparison of time of execution:
 
@@ -530,7 +557,7 @@ module. The restriction under Perl is explained further below.
 
 The above requirements are fulfilled in principle by all Unix or Unix-like systems. 
 
-=head1 Requirement for Full Functionality
+=head1 FULL FUNCTIONALITY REQUIREMENT
 
 The Perl header C<sys/ioctl.ph> is required for the C<ioctl> call of the
 function C<TIOCGWINSZ> to get the window size. The equivalent C/C++ header
@@ -543,7 +570,7 @@ to create a C<sys/ioctl.ph>. This is necessary manually via the C<h2ph> command.
 To prevent tests within CPAN from failing due to a missing C<sys/ioctl.ph>, a
 fallback solution based on the Shell command C<stty> is implemented.   
 
-=head1 ANSI escape sequences versus XTERM control sequences
+=head1 ANSI Escape Sequences Versus XTERM Control Sequences
 
 ANSI escape sequences are widely known. Less well known are the so-called XTERM
 control sequences.
@@ -610,6 +637,12 @@ The following methods have been implemented so far within the module:
 
 =back
 
+=over 4 
+
+=item * ctlseqs_request($parameter, $timeout)
+
+=back
+
 Reading from STDIN is blocking, if no data are available. To overcome the
 problem of waiting endless for user input a timeout is programmed. Unfortunately,
 the programming implementation also slows down the processing when data is available
@@ -617,7 +650,7 @@ in STDIN. If the standard value is not applicable, reduce the timeout step by st
 If the timeout is to short the method is not able to catch the input from STDIN. A
 error code -1 is returned.
 
-=head1 Aliases
+=head1 ALIASES
 
 clear_screen and reset_screen can also be used with this aliases:
 
@@ -626,7 +659,7 @@ clear_screen and reset_screen can also be used with this aliases:
   reset           <=  reset_screen
   clear           <=  clear_screen
 
-=head2 Method description
+=head2 METHOD DESCRIPTION
 
 The method C<clear_screen> is clearing the terminal. This is similar to the
 Perl system command call C<system("clear")>. The method C<reset_screen> is
